@@ -1,6 +1,5 @@
 require 'optparse'
 require 'fileutils'
-require 'rbconfig'
 
 module Haml
   # This module handles the various Haml executables (`haml`, `sass`, `sass-convert`, etc).
@@ -80,7 +79,7 @@ module Haml
           @options[:trace] = true
         end
 
-        if RbConfig::CONFIG['host_os'] =~ /mswin|windows/i
+        if ::Haml::Util.windows?
           opts.on('--unix-newlines', 'Use Unix-style newlines in written files.') do
             @options[:unix_newlines] = true
           end
@@ -317,6 +316,9 @@ END
         opts.on('-I', '--load-path PATH', 'Add a sass import path.') do |path|
           @options[:for_engine][:load_paths] << path
         end
+        opts.on('-r', '--require LIB', 'Require a Ruby library before running Sass.') do |lib|
+          require lib
+        end
         opts.on('--cache-location PATH', 'The path to put cached Sass files. Defaults to .sass-cache.') do |loc|
           @options[:for_engine][:cache_location] = loc
         end
@@ -335,9 +337,9 @@ END
       # and runs the Sass compiler appropriately.
       def process_result
         if !@options[:update] && !@options[:watch] &&
-            @args.first && @args.first.include?(':')
+            @args.first && colon_path?(@args.first)
           if @args.size == 1
-            @args = @args.first.split(':', 2)
+            @args = split_colon_path(@args.first)
           else
             @options[:update] = true
           end
@@ -386,7 +388,7 @@ END
         ::Sass::Plugin.options.merge! @options[:for_engine]
         ::Sass::Plugin.options[:unix_newlines] = @options[:unix_newlines]
 
-        if @args[1] && !@args[0].include?(':')
+        if @args[1] && !colon_path?(@args[0])
           flag = @options[:update] ? "--update" : "--watch"
           err =
             if !File.exist?(@args[1])
@@ -400,7 +402,7 @@ File #{@args[1]} #{err}.
 MSG
         end
 
-        dirs, files = @args.map {|name| name.split(':', 2)}.
+        dirs, files = @args.map {|name| split_colon_path(name)}.
           partition {|i, _| File.directory? i}
         files.map! {|from, to| [from, to || from.gsub(/\..*?$/, '.css')]}
         dirs.map! {|from, to| [from, to || from]}
@@ -434,6 +436,22 @@ MSG
 
         ::Sass::Plugin.watch(files)
       end
+
+      def colon_path?(path)
+        !split_colon_path(path)[1].nil?
+      end
+
+      def split_colon_path(path)
+        one, two = path.split(':', 2)
+        if one && two && ::Haml::Util.windows? &&
+            one =~ /\A[A-Za-z]\Z/ && two =~ /\A[\/\\]/
+          # If we're on Windows and we were passed a drive letter path,
+          # don't split on that colon.
+          one2, two = two.split(':', 2)
+          one = one + ':' + one2
+        end
+        return one, two
+      end
     end
 
     # The `haml` executable.
@@ -700,7 +718,10 @@ END
       private
 
       def process_directory
-        input = @options[:input] = @args.shift
+        unless input = @options[:input] = @args.shift
+          raise "Error: directory required when using --recursive."
+        end
+
         output = @options[:output] = @args.shift
         raise "Error: --from required when using --recursive." unless @options[:from]
         raise "Error: --to required when using --recursive." unless @options[:to]
@@ -710,6 +731,8 @@ END
         end
         @options[:output] ||= @options[:input]
 
+        from = @options[:from]
+        from = :sass if from == :sass2
         if @options[:to] == @options[:from] && !@options[:in_place]
           fmt = @options[:from]
           raise "Error: converting from #{fmt} to #{fmt} without --in-place"
