@@ -242,29 +242,20 @@ END
         # Handle stuff like - end.join("|")
         @to_close_stack.last << false if text =~ /^-\s*end\b/ && !block_opened?
 
-        case_stmt = text =~ /^-\s*case\b/
         keyword = mid_block_keyword?(text)
         block = block_opened? && !keyword
 
         # It's important to preserve tabulation modification for keywords
         # that involve choosing between posible blocks of code.
         if %w[else elsif when].include?(keyword)
-          # @to_close_stack may not have a :script on top
-          # when the preceding "- if" has nothing nested
-          if @to_close_stack.last && @to_close_stack.last.first == :script
-            @dont_indent_next_line, @dont_tab_up_next_text = @to_close_stack.last[1..2]
-          else
-            push_and_tabulate([:script, @dont_indent_next_line, @dont_tab_up_next_text])
-          end
+          @dont_indent_next_line, @dont_tab_up_next_text = @to_close_stack.last[1..2]
 
           # when is unusual in that either it will be indented twice,
           # or the case won't have created its own indentation
           if keyword == "when"
             push_and_tabulate([:script, @dont_indent_next_line, @dont_tab_up_next_text, false])
           end
-        elsif block || case_stmt
-          push_and_tabulate([:script, @dont_indent_next_line, @dont_tab_up_next_text])
-        elsif block && case_stmt
+        elsif block || text =~ /^-\s*(case|if)\b/
           push_and_tabulate([:script, @dont_indent_next_line, @dont_tab_up_next_text])
         end
       when FILTER; start_filtered(text[1..-1].downcase)
@@ -491,7 +482,7 @@ END
     # that can then be merged with another attributes hash.
     def self.parse_class_and_id(list)
       attributes = {}
-      list.scan(/([#.])([-_a-zA-Z0-9]+)/) do |type, property|
+      list.scan(/([#.])([-:_a-zA-Z0-9]+)/) do |type, property|
         case type
         when '.'
           if attributes['class']
@@ -573,7 +564,7 @@ END
 
     # Parses a line into tag_name, attributes, attributes_hash, object_ref, action, value
     def parse_tag(line)
-      raise SyntaxError.new("Invalid tag: \"#{line}\".") unless match = line.scan(/%([-:\w]+)([-\w\.\#]*)(.*)/)[0]
+      raise SyntaxError.new("Invalid tag: \"#{line}\".") unless match = line.scan(/%([-:\w]+)([-:\w\.\#]*)(.*)/)[0]
       tag_name, attributes, rest = match
       new_attributes_hash = old_attributes_hash = last_line = object_ref = nil
       attributes_hashes = []
