@@ -509,16 +509,7 @@ WARNING
       # If value begins with url( or ",
       # it's a CSS @import rule and we don't want to touch it.
       if directive == "import"
-        raise SyntaxError.new("Illegal nesting: Nothing may be nested beneath import directives.",
-          :line => @line + 1) unless line.children.empty?
-        if (match = value.match(Sass::SCSS::RX::STRING) || value.match(Sass::SCSS::RX::URI)) &&
-            !match.post_match.strip.empty? && match.post_match.strip[0] != ?,
-          return Tree::DirectiveNode.new("@import #{value}")
-        end
-        value.split(/,\s*/).map do |f|
-          f = $1 || $2 || $3 if f =~ Sass::SCSS::RX::STRING || f =~ Sass::SCSS::RX::URI
-          Tree::ImportNode.new(f)
-        end
+        parse_import(line, value)
       elsif directive == "mixin"
         parse_mixin_definition(line)
       elsif directive == "include"
@@ -597,6 +588,45 @@ WARNING
       nil
     end
 
+    def parse_import(line, value)
+      raise SyntaxError.new("Illegal nesting: Nothing may be nested beneath import directives.",
+        :line => @line + 1) unless line.children.empty?
+
+      scanner = StringScanner.new(value)
+      values = []
+
+      loop do
+        unless node = parse_import_arg(scanner)
+          raise SyntaxError.new("Invalid @import: expected file to import, was #{scanner.rest.inspect}",
+            :line => @line)
+        end
+        values << node
+        break unless scanner.scan(/,\s*/)
+      end
+
+      return values
+    end
+
+    def parse_import_arg(scanner)
+      return if scanner.eos?
+      unless (str = scanner.scan(Sass::SCSS::RX::STRING)) ||
+          (uri = scanner.scan(Sass::SCSS::RX::URI))
+        return Tree::ImportNode.new(scanner.scan(/[^,]+/))
+      end
+
+      val = scanner[1] || scanner[2]
+      scanner.scan(/\s*/)
+      if media = scanner.scan(/[^,].*/)
+        Tree::DirectiveNode.new("@import #{str || uri} #{media}")
+      elsif uri
+        Tree::DirectiveNode.new("@import #{uri}")
+      elsif val =~ /^http:\/\//
+        Tree::DirectiveNode.new("@import url(#{val})")
+      else
+        Tree::ImportNode.new(val)
+      end
+    end
+
     MIXIN_DEF_RE = /^(?:=|@mixin)\s*(#{Sass::SCSS::RX::IDENT})(.*)$/
     def parse_mixin_definition(line)
       name, arg_string = line.text.scan(MIXIN_DEF_RE).first
