@@ -179,19 +179,33 @@ module Sass
         expr = sass_script(:parse)
         ss
         node = block(node(Sass::Tree::IfNode.new(expr)), :directive)
+        pos = @scanner.pos
         ss
-        else_block(node)
+
+        else_block(node) ||
+          begin
+            # Backtrack in case there are any comments we want to parse
+            @scanner.pos = pos
+            node
+          end
       end
 
       def else_block(node)
-        return node unless tok(/@else/)
+        return unless tok(/@else/)
         ss
         else_node = block(
           Sass::Tree::IfNode.new((sass_script(:parse) if tok(/if/))),
           :directive)
         node.add_else(else_node)
+        pos = @scanner.pos
         ss
-        else_block(node)
+
+        else_block(node) ||
+          begin
+            # Backtrack in case there are any comments we want to parse
+            @scanner.pos = pos
+            node
+          end
       end
 
       def extend_directive
@@ -200,13 +214,13 @@ module Sass
 
       def import_directive
         @expected = "string or url()"
-        arg = tok(STRING) || tok!(URI)
+        arg = tok(STRING) || (uri = tok!(URI))
         path = @scanner[1] || @scanner[2] || @scanner[3]
         ss
 
         media = str {media_query_list}.strip
 
-        if !media.strip.empty? || use_css_import?
+        if uri || path =~ /^http:\/\// || !media.strip.empty? || use_css_import?
           return node(Sass::Tree::DirectiveNode.new("@import #{arg} #{media}".strip))
         end
 
@@ -381,6 +395,17 @@ module Sass
         sel.to_a
       end
 
+      def selector_comma_sequence
+        return unless sel = _selector
+        selectors = [sel]
+        while tok(/,/)
+          ws = str{ss}
+          selectors << expr!(:_selector)
+          selectors[-1] = Selector::Sequence.new(["\n"] + selectors.last.members) if ws.include?("\n")
+        end
+        Selector::CommaSequence.new(selectors)
+      end
+
       def _selector
         # The combinator here allows the "> E" hack
         return unless val = combinator || simple_selector_sequence
@@ -533,12 +558,12 @@ MESSAGE
       end
 
       def negation
-        return unless tok(NOT)
+        return unless name = tok(NOT) || tok(MOZ_ANY)
         ss
         @expected = "selector"
-        sel = element_name || id_selector || class_selector || attrib || expr!(:pseudo)
+        sel = selector_comma_sequence
         tok!(/\)/)
-        Selector::Negation.new(sel)
+        Selector::SelectorPseudoClass.new(name[1...-1], sel)
       end
 
       def declaration
@@ -722,7 +747,7 @@ MESSAGE
         :interp_ident => "identifier",
         :interp_name => "identifier",
         :expr => "expression (e.g. 1px, bold)",
-        :_selector => "selector",
+        :selector_comma_sequence => "selector",
         :simple_selector_sequence => "selector",
       }
 
