@@ -487,8 +487,27 @@ CSS
   end
 
   def test_css_import
-    assert_equal("@import url(./fonts.css) screen;\n", render("@import url(./fonts.css) screen"))
-    assert_equal("@import \"./fonts.css\" screen;\n", render("@import \"./fonts.css\" screen"))
+    assert_equal("@import url(./fonts.css);\n", render("@import \"./fonts.css\""))
+  end
+
+  def test_media_import
+    assert_equal("@import \"./fonts.sass\" all;\n",
+      render("@import \"./fonts.sass\" all"))
+    assert_equal(<<CSS, render(<<SASS))
+@import "./fonts.sass" all;
+@import url(./fonts.scss);
+CSS
+@import "./fonts.sass" all, url(./fonts.scss)
+SASS
+  end
+
+  def test_http_import
+    assert_equal("@import url(http://fonts.googleapis.com/css?family=Droid+Sans);\n",
+      render("@import \"http://fonts.googleapis.com/css?family=Droid+Sans\""))
+  end
+
+  def test_url_import
+    assert_equal("@import url(fonts.sass);\n", render("@import url(fonts.sass)"))
   end
 
   def test_sass_import
@@ -2031,6 +2050,14 @@ SASS
     end
   end
 
+  def test_import_with_commas_in_url
+    assert_equal <<CSS, render(<<SASS)
+@import url(foo.css?bar,baz);
+CSS
+@import url(foo.css?bar,baz)
+SASS
+  end
+
   # Encodings
 
   unless Haml::Util.ruby1_8?
